<?php

namespace Drupal\wordfilter\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class WordfilterConfigurationForm.
 *
 * @package Drupal\wordfilter\Form
 */
class WordfilterConfigurationForm extends EntityForm {

  /**
   * @return \Drupal\wordfilter\Entity\WordfilterConfigurationInterface
   */
  public function getWordfilterConfiguration() {
    return $this->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    $wordfilter_configuration = $this->getWordfilterConfiguration();

    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#maxlength' => 255,
      '#default_value' => $wordfilter_configuration->label(),
      '#description' => $this->t("Label for the Wordfilter configuration."),
      '#required' => TRUE,
    ];

    $form['id'] = [
      '#type' => 'machine_name',
      '#default_value' => $wordfilter_configuration->id(),
      '#machine_name' => [
        'exists' => '\Drupal\wordfilter\Entity\WordfilterConfiguration::load',
      ],
      '#disabled' => !$wordfilter_configuration->isNew(),
    ];

    $form['substitute'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Substitution text'),
      '#maxlength' => 255,
      '#default_value' => $wordfilter_configuration->getSubstitute(),
      '#description' => $this->t('Any filtered word will be replaced by this substitution text (optional).'),
      '#required' => FALSE,
    ];

    $form['filter_words'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Words to filter'),
      '#default_value' => implode(', ', $wordfilter_configuration->getFilterWords()),
      '#description' => \Drupal::theme()->render('item_list', ['items' => [
        $this->t('Enter a <strong>comma-separated</strong> list of filter words.'),
        $this->t('Example: <em>Somebadword, Another, [placeholder]</em>.'),
      ]]),
      '#required' => FALSE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $wordfilter_configuration = $this->getWordfilterConfiguration();

    // Manually set the values of filter words to guarantee a compatible list.
    $filter_words = $form_state->getValue('filter_words');
    $wordfilter_configuration->setFilterWords($filter_words);

    $status = $wordfilter_configuration->save();

    switch ($status) {
      case SAVED_NEW:
        drupal_set_message($this->t('Created the %label Wordfilter configuration.', [
          '%label' => $wordfilter_configuration->label(),
        ]));
        break;

      default:
        drupal_set_message($this->t('Saved the %label Wordfilter configuration.', [
          '%label' => $wordfilter_configuration->label(),
        ]));
    }
    $form_state->setRedirectUrl($wordfilter_configuration->urlInfo('collection'));
  }

}
