<?php

namespace Drupal\Tests\wordfilter\Unit;

use \Drupal\Tests\UnitTestCase;
use \Drupal\wordfilter\Entity\WordfilterConfiguration;
use \Drupal\wordfilter\WordfilterLibrary;

/**
 * @coversDefaultClass \Drupal\wordfilter\WordfilterLibrary
 * @group filter
 */
class WordfilterUnitTest extends UnitTestCase {

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
  }

  /**
   * @covers ::filterWords
   *
   * @dataProvider providerFilterWords
   *
   * @param $text
   *   An unfiltered string with words.
   * @param $expected
   *   The expected output string.
   */
  public function testfilterWords($text, $expected) {
    $wordfilter_config = new WordfilterConfiguration([
      'id' => 'my_superduper_wordfilter_configuration',
      'label' => 'My superduper Wordfilter configuration'],
      'wordfilter_configuration');
    $wordfilter_config->setFilterWords(['(Lorem)', 'Dolor', 'Amet']);
    $wordfilter_config->setSubstitute('***');

    $this->assertSame($expected, WordfilterLibrary::filterWords($text, $wordfilter_config));
  }

  /**
   * Data provider for testfilterWords().
   *
   * TODO Add more reasonable data sets.
   *
   * @return array
   */
  public function providerFilterWords() {
    return [
      ['Lorem Ipsum Dolor Sit Amet', 'Lorem Ipsum *** Sit ***'],
      ['lorem ipsum dolor sit amet', 'lorem ipsum *** sit ***'],
      ['LoremIpsumDolorSitAmet', 'LoremIpsumDolorSitAmet'],
      ['(Lorem) *Ipsum* *Dolor* *Sit* *Amet*', '*** *Ipsum* ***** *Sit* *****'],
    ];
  }
}
